aboutsummaryrefslogtreecommitdiffstats
path: root/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
diff options
context:
space:
mode:
authorJosephKeenan <joseph.keenan@est.tech>2021-11-23 12:18:28 +0000
committerJosephKeenan <joseph.keenan@est.tech>2021-11-25 15:40:10 +0000
commit20b4f9cf0b662de4a7665b2a82593ef0205f5e06 (patch)
treeab849ff17b861f246c328e421e8dcfc8ceb9e851 /cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
parentbc742a1dbe39a3269abab9e62a9d489f460144b0 (diff)
Allow separate registration of DMIDataPlugin and DmiModelPugin
Moved relevant code from NetworkCmProxyDataServiceImp to DmiOperations Split DmiOperations into DMiData... and DMIModelOperations Merged update-operation changes Added tests for error message validation in NetworkCmProxyDataServiceImplSpec Removede @Service from DMIOperations and added @component to DmiDataOperations & DmiModelOperations Verify sync robot test is now hardened Added exitonfailure so robot tests stop after first encountered failed test Issue-ID: CPS-736 Change-Id: I0b40931cc8cd4fc0452328a0a7e0f60e6fc38d0a Signed-off-by: JosephKeenan <joseph.keenan@est.tech> Signed-off-by: ToineSiebelink <toine.siebelink@est.tech> Signed-off-by: DylanB95EST <dylan.byrne@est.tech>
Diffstat (limited to 'cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java')
-rw-r--r--cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java38
1 files changed, 15 insertions, 23 deletions
diff --git a/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java b/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
index 45d5bd911..ec816ed73 100644
--- a/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
+++ b/cps-ncmp-service/src/main/java/org/onap/cps/ncmp/api/NetworkCmProxyDataService.java
@@ -22,8 +22,9 @@
package org.onap.cps.ncmp.api;
+import static org.onap.cps.ncmp.api.impl.operations.DmiRequestBody.OperationEnum;
+
import java.util.Collection;
-import javax.validation.constraints.NotNull;
import org.checkerframework.checker.nullness.qual.NonNull;
import org.onap.cps.ncmp.api.models.DmiPluginRegistration;
import org.onap.cps.spi.FetchDescendantsOption;
@@ -118,8 +119,8 @@ public interface NetworkCmProxyDataService {
* @param optionsParamInQuery options query
* @return {@code Object} resource data
*/
- Object getResourceDataOperationalForCmHandle(@NotNull String cmHandle,
- @NotNull String resourceIdentifier,
+ Object getResourceDataOperationalForCmHandle(String cmHandle,
+ String resourceIdentifier,
String acceptParamInHeader,
String optionsParamInQuery);
@@ -133,24 +134,25 @@ public interface NetworkCmProxyDataService {
* @param optionsParamInQuery options query
* @return {@code Object} resource data
*/
- Object getResourceDataPassThroughRunningForCmHandle(@NotNull String cmHandle,
- @NotNull String resourceIdentifier,
+ Object getResourceDataPassThroughRunningForCmHandle(String cmHandle,
+ String resourceIdentifier,
String acceptParamInHeader,
String optionsParamInQuery);
/**
* Create resource data for data store pass-through running
* using dmi for given cm-handle.
- *
- * @param cmHandle cm handle
+ * @param cmHandle cm handle
* @param resourceIdentifier resource identifier
+ * @param operation required operation
* @param requestBody request body to create resource
* @param contentType content type in body
*/
- void createResourceDataPassThroughRunningForCmHandle(@NotNull String cmHandle,
- @NotNull String resourceIdentifier,
- @NotNull String requestBody,
- String contentType);
+ void writeResourceDataPassThroughRunningForCmHandle(String cmHandle,
+ String resourceIdentifier,
+ OperationEnum operation,
+ String requestBody,
+ String contentType);
/**
* Retrieve module references for the given cm handle.
@@ -158,7 +160,7 @@ public interface NetworkCmProxyDataService {
* @param cmHandle cm handle
* @return a collection of modules names and revisions
*/
- Collection<ModuleReference> getYangResourcesModuleReferences(@NotNull String cmHandle);
+ Collection<ModuleReference> getYangResourcesModuleReferences(String cmHandle);
/**
* Query cm handle identifiers for the given collection of module names.
@@ -169,14 +171,4 @@ public interface NetworkCmProxyDataService {
*/
Collection<String> executeCmHandleHasAllModulesSearch(Collection<String> moduleNames);
- /**
- * Update resource data for data store pass-through running using dmi for the given cm-handle.
- *
- * @param cmHandle cm handle
- * @param resourceIdentifier resource identifier
- * @param requestBody request body to create resource
- * @param contentType content type in body
- */
- void updateResourceDataPassThroughRunningForCmHandle(String cmHandle, String resourceIdentifier,
- String requestBody, String contentType);
}
@@ -133,24 +134,25 @@ public interface NetworkCmProxyDataService {
String optionsParamInQuery);
/**
- * Create resource data for data store pass-through running
+ * Write resource data for data store pass-through running
* using dmi for given cm-handle.